==> Pyrogram-2.0.2-py3-none-any.whl: pyrogram/raw/base/document_attribute.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

DocumentAttribute = Union[raw.types.DocumentAttributeAnimated, raw.types.DocumentAttributeAudio, raw.types.DocumentAttributeFilename, raw.types.DocumentAttributeHasStickers, raw.types.DocumentAttributeImageSize, raw.types.DocumentAttributeSticker, raw.types.DocumentAttributeVideo]


# noinspection PyRedeclaration
class DocumentAttribute:  # type: ignore
    """This base type has 7 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`DocumentAttributeAnimated <pyrogram.raw.types.DocumentAttributeAnimated>`
            - :obj:`DocumentAttributeAudio <pyrogram.raw.types.DocumentAttributeAudio>`
            - :obj:`DocumentAttributeFilename <pyrogram.raw.types.DocumentAttributeFilename>`
            - :obj:`DocumentAttributeHasStickers <pyrogram.raw.types.DocumentAttributeHasStickers>`
            - :obj:`DocumentAttributeImageSize <pyrogram.raw.types.DocumentAttributeImageSize>`
            - :obj:`DocumentAttributeSticker <pyrogram.raw.types.DocumentAttributeSticker>`
            - :obj:`DocumentAttributeVideo <pyrogram.raw.types.DocumentAttributeVideo>`
    """

    QUALNAME = "pyrogram.raw.base.DocumentAttribute"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/document-attribute")

==> Pyrogram-2.0.36-py3-none-any.whl: pyrogram/raw/base/document_attribute.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

DocumentAttribute = Union[raw.types.DocumentAttributeAnimated, raw.types.DocumentAttributeAudio, raw.types.DocumentAttributeCustomEmoji, raw.types.DocumentAttributeFilename, raw.types.DocumentAttributeHasStickers, raw.types.DocumentAttributeImageSize, raw.types.DocumentAttributeSticker, raw.types.DocumentAttributeVideo]


# noinspection PyRedeclaration
class DocumentAttribute:  # type: ignore
    """This base type has 8 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`DocumentAttributeAnimated <pyrogram.raw.types.DocumentAttributeAnimated>`
            - :obj:`DocumentAttributeAudio <pyrogram.raw.types.DocumentAttributeAudio>`
            - :obj:`DocumentAttributeCustomEmoji <pyrogram.raw.types.DocumentAttributeCustomEmoji>`
            - :obj:`DocumentAttributeFilename <pyrogram.raw.types.DocumentAttributeFilename>`
            - :obj:`DocumentAttributeHasStickers <pyrogram.raw.types.DocumentAttributeHasStickers>`
            - :obj:`DocumentAttributeImageSize <pyrogram.raw.types.DocumentAttributeImageSize>`
            - :obj:`DocumentAttributeSticker <pyrogram.raw.types.DocumentAttributeSticker>`
            - :obj:`DocumentAttributeVideo <pyrogram.raw.types.DocumentAttributeVideo>`
    """

    QUALNAME = "pyrogram.raw.base.DocumentAttribute"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/document-attribute")
